#[cfg(feature = "Win32_Graphics_Direct3D_Dxc")]
pub mod Dxc;
#[cfg(feature = "Win32_Graphics_Direct3D_Fxc")]
pub mod Fxc;
#[repr(C)]
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub struct D3DMATRIX {
    pub Anonymous: D3DMATRIX_0,
}
impl ::core::marker::Copy for D3DMATRIX {}
impl ::core::clone::Clone for D3DMATRIX {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub union D3DMATRIX_0 {
    pub Anonymous: D3DMATRIX_0_0,
    pub m: [f32; 16],
}
impl ::core::marker::Copy for D3DMATRIX_0 {}
impl ::core::clone::Clone for D3DMATRIX_0 {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub struct D3DMATRIX_0_0 {
    pub _11: f32,
    pub _12: f32,
    pub _13: f32,
    pub _14: f32,
    pub _21: f32,
    pub _22: f32,
    pub _23: f32,
    pub _24: f32,
    pub _31: f32,
    pub _32: f32,
    pub _33: f32,
    pub _34: f32,
    pub _41: f32,
    pub _42: f32,
    pub _43: f32,
    pub _44: f32,
}
impl ::core::marker::Copy for D3DMATRIX_0_0 {}
impl ::core::clone::Clone for D3DMATRIX_0_0 {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub struct D3DVECTOR {
    pub x: f32,
    pub y: f32,
    pub z: f32,
}
impl ::core::marker::Copy for D3DVECTOR {}
impl ::core::clone::Clone for D3DVECTOR {
    fn clone(&self) -> Self {
        *self
    }
}
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_CBUFFER_TYPE = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_CT_CBUFFER: D3D_CBUFFER_TYPE = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_CT_TBUFFER: D3D_CBUFFER_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_CT_INTERFACE_POINTERS: D3D_CBUFFER_TYPE = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_CT_RESOURCE_BIND_INFO: D3D_CBUFFER_TYPE = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_CT_CBUFFER: D3D_CBUFFER_TYPE = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_CT_TBUFFER: D3D_CBUFFER_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_CT_CBUFFER: D3D_CBUFFER_TYPE = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_CT_TBUFFER: D3D_CBUFFER_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_CT_INTERFACE_POINTERS: D3D_CBUFFER_TYPE = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_CT_RESOURCE_BIND_INFO: D3D_CBUFFER_TYPE = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_COMPONENT_MASK_W: u32 = 8u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_COMPONENT_MASK_X: u32 = 1u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_COMPONENT_MASK_Y: u32 = 2u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_COMPONENT_MASK_Z: u32 = 4u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_DRIVER_TYPE = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_DRIVER_TYPE_UNKNOWN: D3D_DRIVER_TYPE = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_DRIVER_TYPE_HARDWARE: D3D_DRIVER_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_DRIVER_TYPE_REFERENCE: D3D_DRIVER_TYPE = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_DRIVER_TYPE_NULL: D3D_DRIVER_TYPE = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_DRIVER_TYPE_SOFTWARE: D3D_DRIVER_TYPE = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_DRIVER_TYPE_WARP: D3D_DRIVER_TYPE = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_FEATURE_LEVEL = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FEATURE_LEVEL_1_0_CORE: D3D_FEATURE_LEVEL = 4096i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FEATURE_LEVEL_9_1: D3D_FEATURE_LEVEL = 37120i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FEATURE_LEVEL_9_2: D3D_FEATURE_LEVEL = 37376i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FEATURE_LEVEL_9_3: D3D_FEATURE_LEVEL = 37632i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FEATURE_LEVEL_10_0: D3D_FEATURE_LEVEL = 40960i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FEATURE_LEVEL_10_1: D3D_FEATURE_LEVEL = 41216i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FEATURE_LEVEL_11_0: D3D_FEATURE_LEVEL = 45056i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FEATURE_LEVEL_11_1: D3D_FEATURE_LEVEL = 45312i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FEATURE_LEVEL_12_0: D3D_FEATURE_LEVEL = 49152i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FEATURE_LEVEL_12_1: D3D_FEATURE_LEVEL = 49408i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FEATURE_LEVEL_12_2: D3D_FEATURE_LEVEL = 49664i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FL9_1_DEFAULT_MAX_ANISOTROPY: u32 = 2u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FL9_1_IA_PRIMITIVE_MAX_COUNT: u32 = 65535u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FL9_1_MAX_TEXTURE_REPEAT: u32 = 128u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FL9_1_REQ_TEXTURE1D_U_DIMENSION: u32 = 2048u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FL9_1_REQ_TEXTURE2D_U_OR_V_DIMENSION: u32 = 2048u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FL9_1_REQ_TEXTURE3D_U_V_OR_W_DIMENSION: u32 = 256u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FL9_1_REQ_TEXTURECUBE_DIMENSION: u32 = 512u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FL9_1_SIMULTANEOUS_RENDER_TARGET_COUNT: u32 = 1u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FL9_2_IA_PRIMITIVE_MAX_COUNT: u32 = 1048575u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FL9_2_MAX_TEXTURE_REPEAT: u32 = 2048u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FL9_3_MAX_TEXTURE_REPEAT: u32 = 8192u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FL9_3_REQ_TEXTURE1D_U_DIMENSION: u32 = 4096u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FL9_3_REQ_TEXTURE2D_U_OR_V_DIMENSION: u32 = 4096u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FL9_3_REQ_TEXTURECUBE_DIMENSION: u32 = 4096u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_FL9_3_SIMULTANEOUS_RENDER_TARGET_COUNT: u32 = 4u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_INCLUDE_TYPE = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_INCLUDE_LOCAL: D3D_INCLUDE_TYPE = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_INCLUDE_SYSTEM: D3D_INCLUDE_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_INCLUDE_LOCAL: D3D_INCLUDE_TYPE = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_INCLUDE_SYSTEM: D3D_INCLUDE_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_INCLUDE_FORCE_DWORD: D3D_INCLUDE_TYPE = 2147483647i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_INTERPOLATION_MODE = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_INTERPOLATION_UNDEFINED: D3D_INTERPOLATION_MODE = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_INTERPOLATION_CONSTANT: D3D_INTERPOLATION_MODE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_INTERPOLATION_LINEAR: D3D_INTERPOLATION_MODE = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_INTERPOLATION_LINEAR_CENTROID: D3D_INTERPOLATION_MODE = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_INTERPOLATION_LINEAR_NOPERSPECTIVE: D3D_INTERPOLATION_MODE = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_INTERPOLATION_LINEAR_NOPERSPECTIVE_CENTROID: D3D_INTERPOLATION_MODE = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_INTERPOLATION_LINEAR_SAMPLE: D3D_INTERPOLATION_MODE = 6i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_INTERPOLATION_LINEAR_NOPERSPECTIVE_SAMPLE: D3D_INTERPOLATION_MODE = 7i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_MIN_PRECISION = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_MIN_PRECISION_DEFAULT: D3D_MIN_PRECISION = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_MIN_PRECISION_FLOAT_16: D3D_MIN_PRECISION = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_MIN_PRECISION_FLOAT_2_8: D3D_MIN_PRECISION = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_MIN_PRECISION_RESERVED: D3D_MIN_PRECISION = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_MIN_PRECISION_SINT_16: D3D_MIN_PRECISION = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_MIN_PRECISION_UINT_16: D3D_MIN_PRECISION = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_MIN_PRECISION_ANY_16: D3D_MIN_PRECISION = 240i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_MIN_PRECISION_ANY_10: D3D_MIN_PRECISION = 241i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_NAME = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_UNDEFINED: D3D_NAME = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_POSITION: D3D_NAME = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_CLIP_DISTANCE: D3D_NAME = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_CULL_DISTANCE: D3D_NAME = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_RENDER_TARGET_ARRAY_INDEX: D3D_NAME = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_VIEWPORT_ARRAY_INDEX: D3D_NAME = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_VERTEX_ID: D3D_NAME = 6i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_PRIMITIVE_ID: D3D_NAME = 7i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_INSTANCE_ID: D3D_NAME = 8i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_IS_FRONT_FACE: D3D_NAME = 9i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_SAMPLE_INDEX: D3D_NAME = 10i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_FINAL_QUAD_EDGE_TESSFACTOR: D3D_NAME = 11i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_FINAL_QUAD_INSIDE_TESSFACTOR: D3D_NAME = 12i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_FINAL_TRI_EDGE_TESSFACTOR: D3D_NAME = 13i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_FINAL_TRI_INSIDE_TESSFACTOR: D3D_NAME = 14i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_FINAL_LINE_DETAIL_TESSFACTOR: D3D_NAME = 15i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_FINAL_LINE_DENSITY_TESSFACTOR: D3D_NAME = 16i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_BARYCENTRICS: D3D_NAME = 23i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_SHADINGRATE: D3D_NAME = 24i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_CULLPRIMITIVE: D3D_NAME = 25i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_TARGET: D3D_NAME = 64i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_DEPTH: D3D_NAME = 65i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_COVERAGE: D3D_NAME = 66i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_DEPTH_GREATER_EQUAL: D3D_NAME = 67i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_DEPTH_LESS_EQUAL: D3D_NAME = 68i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_STENCIL_REF: D3D_NAME = 69i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_NAME_INNER_COVERAGE: D3D_NAME = 70i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_NAME_UNDEFINED: D3D_NAME = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_NAME_POSITION: D3D_NAME = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_NAME_CLIP_DISTANCE: D3D_NAME = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_NAME_CULL_DISTANCE: D3D_NAME = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_NAME_RENDER_TARGET_ARRAY_INDEX: D3D_NAME = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_NAME_VIEWPORT_ARRAY_INDEX: D3D_NAME = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_NAME_VERTEX_ID: D3D_NAME = 6i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_NAME_PRIMITIVE_ID: D3D_NAME = 7i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_NAME_INSTANCE_ID: D3D_NAME = 8i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_NAME_IS_FRONT_FACE: D3D_NAME = 9i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_NAME_SAMPLE_INDEX: D3D_NAME = 10i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_NAME_TARGET: D3D_NAME = 64i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_NAME_DEPTH: D3D_NAME = 65i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_NAME_COVERAGE: D3D_NAME = 66i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_NAME_FINAL_QUAD_EDGE_TESSFACTOR: D3D_NAME = 11i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_NAME_FINAL_QUAD_INSIDE_TESSFACTOR: D3D_NAME = 12i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_NAME_FINAL_TRI_EDGE_TESSFACTOR: D3D_NAME = 13i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_NAME_FINAL_TRI_INSIDE_TESSFACTOR: D3D_NAME = 14i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_NAME_FINAL_LINE_DETAIL_TESSFACTOR: D3D_NAME = 15i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_NAME_FINAL_LINE_DENSITY_TESSFACTOR: D3D_NAME = 16i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_NAME_DEPTH_GREATER_EQUAL: D3D_NAME = 67i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_NAME_DEPTH_LESS_EQUAL: D3D_NAME = 68i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_NAME_STENCIL_REF: D3D_NAME = 69i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_NAME_INNER_COVERAGE: D3D_NAME = 70i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D12_NAME_BARYCENTRICS: D3D_NAME = 23i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D12_NAME_SHADINGRATE: D3D_NAME = 24i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D12_NAME_CULLPRIMITIVE: D3D_NAME = 25i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_PARAMETER_FLAGS = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PF_NONE: D3D_PARAMETER_FLAGS = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PF_IN: D3D_PARAMETER_FLAGS = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PF_OUT: D3D_PARAMETER_FLAGS = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PF_FORCE_DWORD: D3D_PARAMETER_FLAGS = 2147483647i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_PRIMITIVE = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_UNDEFINED: D3D_PRIMITIVE = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_POINT: D3D_PRIMITIVE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_LINE: D3D_PRIMITIVE = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TRIANGLE: D3D_PRIMITIVE = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_LINE_ADJ: D3D_PRIMITIVE = 6i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TRIANGLE_ADJ: D3D_PRIMITIVE = 7i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_1_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 8i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_2_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 9i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_3_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 10i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_4_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 11i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_5_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 12i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_6_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 13i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_7_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 14i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_8_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 15i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_9_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 16i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_10_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 17i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_11_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 18i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_12_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 19i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_13_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 20i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_14_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 21i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_15_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 22i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_16_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 23i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_17_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 24i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_18_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 25i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_19_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 26i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_20_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 27i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_21_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 28i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_22_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 29i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_23_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 30i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_24_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 31i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_25_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 32i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_26_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 33i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_27_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 34i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_28_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 35i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_29_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 36i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_30_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 37i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_31_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 38i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_32_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 39i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_PRIMITIVE_UNDEFINED: D3D_PRIMITIVE = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_PRIMITIVE_POINT: D3D_PRIMITIVE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_PRIMITIVE_LINE: D3D_PRIMITIVE = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_PRIMITIVE_TRIANGLE: D3D_PRIMITIVE = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_PRIMITIVE_LINE_ADJ: D3D_PRIMITIVE = 6i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_PRIMITIVE_TRIANGLE_ADJ: D3D_PRIMITIVE = 7i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_UNDEFINED: D3D_PRIMITIVE = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_POINT: D3D_PRIMITIVE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_LINE: D3D_PRIMITIVE = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TRIANGLE: D3D_PRIMITIVE = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_LINE_ADJ: D3D_PRIMITIVE = 6i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TRIANGLE_ADJ: D3D_PRIMITIVE = 7i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_1_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 8i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_2_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 9i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_3_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 10i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_4_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 11i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_5_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 12i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_6_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 13i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_7_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 14i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_8_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 15i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_9_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 16i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_10_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 17i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_11_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 18i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_12_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 19i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_13_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 20i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_14_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 21i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_15_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 22i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_16_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 23i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_17_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 24i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_18_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 25i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_19_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 26i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_20_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 27i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_21_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 28i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_22_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 29i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_23_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 30i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_24_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 31i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_25_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 32i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_26_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 33i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_27_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 34i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_28_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 35i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_29_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 36i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_30_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 37i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_31_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 38i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_32_CONTROL_POINT_PATCH: D3D_PRIMITIVE = 39i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_PRIMITIVE_TOPOLOGY = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_UNDEFINED: D3D_PRIMITIVE_TOPOLOGY = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_POINTLIST: D3D_PRIMITIVE_TOPOLOGY = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_LINELIST: D3D_PRIMITIVE_TOPOLOGY = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_LINESTRIP: D3D_PRIMITIVE_TOPOLOGY = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_TRIANGLELIST: D3D_PRIMITIVE_TOPOLOGY = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP: D3D_PRIMITIVE_TOPOLOGY = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_LINELIST_ADJ: D3D_PRIMITIVE_TOPOLOGY = 10i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_LINESTRIP_ADJ: D3D_PRIMITIVE_TOPOLOGY = 11i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_TRIANGLELIST_ADJ: D3D_PRIMITIVE_TOPOLOGY = 12i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP_ADJ: D3D_PRIMITIVE_TOPOLOGY = 13i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_1_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 33i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_2_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 34i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_3_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 35i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_4_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 36i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_5_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 37i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_6_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 38i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_7_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 39i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_8_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 40i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_9_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 41i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_10_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 42i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_11_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 43i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_12_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 44i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_13_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 45i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_14_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 46i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_15_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 47i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_16_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 48i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_17_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 49i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_18_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 50i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_19_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 51i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_20_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 52i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_21_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 53i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_22_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 54i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_23_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 55i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_24_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 56i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_25_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 57i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_26_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 58i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_27_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 59i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_28_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 60i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_29_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 61i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_30_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 62i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_31_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 63i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_PRIMITIVE_TOPOLOGY_32_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 64i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_PRIMITIVE_TOPOLOGY_UNDEFINED: D3D_PRIMITIVE_TOPOLOGY = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_PRIMITIVE_TOPOLOGY_POINTLIST: D3D_PRIMITIVE_TOPOLOGY = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_PRIMITIVE_TOPOLOGY_LINELIST: D3D_PRIMITIVE_TOPOLOGY = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_PRIMITIVE_TOPOLOGY_LINESTRIP: D3D_PRIMITIVE_TOPOLOGY = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_PRIMITIVE_TOPOLOGY_TRIANGLELIST: D3D_PRIMITIVE_TOPOLOGY = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP: D3D_PRIMITIVE_TOPOLOGY = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_PRIMITIVE_TOPOLOGY_LINELIST_ADJ: D3D_PRIMITIVE_TOPOLOGY = 10i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_PRIMITIVE_TOPOLOGY_LINESTRIP_ADJ: D3D_PRIMITIVE_TOPOLOGY = 11i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_PRIMITIVE_TOPOLOGY_TRIANGLELIST_ADJ: D3D_PRIMITIVE_TOPOLOGY = 12i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP_ADJ: D3D_PRIMITIVE_TOPOLOGY = 13i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_UNDEFINED: D3D_PRIMITIVE_TOPOLOGY = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_POINTLIST: D3D_PRIMITIVE_TOPOLOGY = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_LINELIST: D3D_PRIMITIVE_TOPOLOGY = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_LINESTRIP: D3D_PRIMITIVE_TOPOLOGY = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_TRIANGLELIST: D3D_PRIMITIVE_TOPOLOGY = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP: D3D_PRIMITIVE_TOPOLOGY = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_LINELIST_ADJ: D3D_PRIMITIVE_TOPOLOGY = 10i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_LINESTRIP_ADJ: D3D_PRIMITIVE_TOPOLOGY = 11i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_TRIANGLELIST_ADJ: D3D_PRIMITIVE_TOPOLOGY = 12i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_TRIANGLESTRIP_ADJ: D3D_PRIMITIVE_TOPOLOGY = 13i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_1_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 33i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_2_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 34i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_3_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 35i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_4_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 36i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_5_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 37i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_6_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 38i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_7_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 39i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_8_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 40i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_9_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 41i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_10_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 42i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_11_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 43i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_12_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 44i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_13_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 45i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_14_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 46i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_15_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 47i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_16_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 48i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_17_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 49i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_18_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 50i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_19_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 51i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_20_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 52i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_21_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 53i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_22_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 54i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_23_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 55i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_24_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 56i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_25_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 57i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_26_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 58i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_27_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 59i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_28_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 60i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_29_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 61i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_30_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 62i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_31_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 63i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_PRIMITIVE_TOPOLOGY_32_CONTROL_POINT_PATCHLIST: D3D_PRIMITIVE_TOPOLOGY = 64i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_REGISTER_COMPONENT_TYPE = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_REGISTER_COMPONENT_UNKNOWN: D3D_REGISTER_COMPONENT_TYPE = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_REGISTER_COMPONENT_UINT32: D3D_REGISTER_COMPONENT_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_REGISTER_COMPONENT_SINT32: D3D_REGISTER_COMPONENT_TYPE = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_REGISTER_COMPONENT_FLOAT32: D3D_REGISTER_COMPONENT_TYPE = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_REGISTER_COMPONENT_UNKNOWN: D3D_REGISTER_COMPONENT_TYPE = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_REGISTER_COMPONENT_UINT32: D3D_REGISTER_COMPONENT_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_REGISTER_COMPONENT_SINT32: D3D_REGISTER_COMPONENT_TYPE = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_REGISTER_COMPONENT_FLOAT32: D3D_REGISTER_COMPONENT_TYPE = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_RESOURCE_RETURN_TYPE = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_RETURN_TYPE_UNORM: D3D_RESOURCE_RETURN_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_RETURN_TYPE_SNORM: D3D_RESOURCE_RETURN_TYPE = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_RETURN_TYPE_SINT: D3D_RESOURCE_RETURN_TYPE = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_RETURN_TYPE_UINT: D3D_RESOURCE_RETURN_TYPE = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_RETURN_TYPE_FLOAT: D3D_RESOURCE_RETURN_TYPE = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_RETURN_TYPE_MIXED: D3D_RESOURCE_RETURN_TYPE = 6i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_RETURN_TYPE_DOUBLE: D3D_RESOURCE_RETURN_TYPE = 7i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_RETURN_TYPE_CONTINUED: D3D_RESOURCE_RETURN_TYPE = 8i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_RETURN_TYPE_UNORM: D3D_RESOURCE_RETURN_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_RETURN_TYPE_SNORM: D3D_RESOURCE_RETURN_TYPE = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_RETURN_TYPE_SINT: D3D_RESOURCE_RETURN_TYPE = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_RETURN_TYPE_UINT: D3D_RESOURCE_RETURN_TYPE = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_RETURN_TYPE_FLOAT: D3D_RESOURCE_RETURN_TYPE = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_RETURN_TYPE_MIXED: D3D_RESOURCE_RETURN_TYPE = 6i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_RETURN_TYPE_UNORM: D3D_RESOURCE_RETURN_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_RETURN_TYPE_SNORM: D3D_RESOURCE_RETURN_TYPE = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_RETURN_TYPE_SINT: D3D_RESOURCE_RETURN_TYPE = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_RETURN_TYPE_UINT: D3D_RESOURCE_RETURN_TYPE = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_RETURN_TYPE_FLOAT: D3D_RESOURCE_RETURN_TYPE = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_RETURN_TYPE_MIXED: D3D_RESOURCE_RETURN_TYPE = 6i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_RETURN_TYPE_DOUBLE: D3D_RESOURCE_RETURN_TYPE = 7i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_RETURN_TYPE_CONTINUED: D3D_RESOURCE_RETURN_TYPE = 8i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_SHADER_CBUFFER_FLAGS = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_CBF_USERPACKED: D3D_SHADER_CBUFFER_FLAGS = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_CBF_USERPACKED: D3D_SHADER_CBUFFER_FLAGS = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_CBF_FORCE_DWORD: D3D_SHADER_CBUFFER_FLAGS = 2147483647i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_11_1_DOUBLE_EXTENSIONS: u32 = 32u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_11_1_SHADER_EXTENSIONS: u32 = 64u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_64_UAVS: u32 = 8u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_ATOMIC_INT64_ON_DESCRIPTOR_HEAP_RESOURCE: u32 = 268435456u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_ATOMIC_INT64_ON_GROUP_SHARED: u32 = 8388608u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_ATOMIC_INT64_ON_TYPED_RESOURCE: u32 = 4194304u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_BARYCENTRICS: u32 = 131072u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_COMPUTE_SHADERS_PLUS_RAW_AND_STRUCTURED_BUFFERS_VIA_SHADER_4_X: u32 = 2u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_DERIVATIVES_IN_MESH_AND_AMPLIFICATION_SHADERS: u32 = 16777216u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_DOUBLES: u32 = 1u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_INNER_COVERAGE: u32 = 1024u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_INT64_OPS: u32 = 32768u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_LEVEL_9_COMPARISON_FILTERING: u32 = 128u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_MINIMUM_PRECISION: u32 = 16u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_NATIVE_16BIT_OPS: u32 = 262144u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_RAYTRACING_TIER_1_1: u32 = 1048576u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_RESOURCE_DESCRIPTOR_HEAP_INDEXING: u32 = 33554432u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_ROVS: u32 = 4096u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_SAMPLER_DESCRIPTOR_HEAP_INDEXING: u32 = 67108864u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_SAMPLER_FEEDBACK: u32 = 2097152u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_SHADING_RATE: u32 = 524288u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_STENCIL_REF: u32 = 512u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_TILED_RESOURCES: u32 = 256u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_TYPED_UAV_LOAD_ADDITIONAL_FORMATS: u32 = 2048u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_UAVS_AT_EVERY_STAGE: u32 = 4u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_VIEWPORT_AND_RT_ARRAY_INDEX_FROM_ANY_SHADER_FEEDING_RASTERIZER: u32 = 8192u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_VIEW_ID: u32 = 65536u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_WAVE_MMA: u32 = 134217728u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SHADER_FEATURE_WAVE_OPS: u32 = 16384u32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_SHADER_INPUT_FLAGS = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIF_USERPACKED: D3D_SHADER_INPUT_FLAGS = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIF_COMPARISON_SAMPLER: D3D_SHADER_INPUT_FLAGS = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIF_TEXTURE_COMPONENT_0: D3D_SHADER_INPUT_FLAGS = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIF_TEXTURE_COMPONENT_1: D3D_SHADER_INPUT_FLAGS = 8i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIF_TEXTURE_COMPONENTS: D3D_SHADER_INPUT_FLAGS = 12i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIF_UNUSED: D3D_SHADER_INPUT_FLAGS = 16i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SIF_USERPACKED: D3D_SHADER_INPUT_FLAGS = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SIF_COMPARISON_SAMPLER: D3D_SHADER_INPUT_FLAGS = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SIF_TEXTURE_COMPONENT_0: D3D_SHADER_INPUT_FLAGS = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SIF_TEXTURE_COMPONENT_1: D3D_SHADER_INPUT_FLAGS = 8i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SIF_TEXTURE_COMPONENTS: D3D_SHADER_INPUT_FLAGS = 12i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIF_FORCE_DWORD: D3D_SHADER_INPUT_FLAGS = 2147483647i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_SHADER_INPUT_TYPE = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIT_CBUFFER: D3D_SHADER_INPUT_TYPE = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIT_TBUFFER: D3D_SHADER_INPUT_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIT_TEXTURE: D3D_SHADER_INPUT_TYPE = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIT_SAMPLER: D3D_SHADER_INPUT_TYPE = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIT_UAV_RWTYPED: D3D_SHADER_INPUT_TYPE = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIT_STRUCTURED: D3D_SHADER_INPUT_TYPE = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIT_UAV_RWSTRUCTURED: D3D_SHADER_INPUT_TYPE = 6i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIT_BYTEADDRESS: D3D_SHADER_INPUT_TYPE = 7i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIT_UAV_RWBYTEADDRESS: D3D_SHADER_INPUT_TYPE = 8i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIT_UAV_APPEND_STRUCTURED: D3D_SHADER_INPUT_TYPE = 9i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIT_UAV_CONSUME_STRUCTURED: D3D_SHADER_INPUT_TYPE = 10i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIT_UAV_RWSTRUCTURED_WITH_COUNTER: D3D_SHADER_INPUT_TYPE = 11i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIT_RTACCELERATIONSTRUCTURE: D3D_SHADER_INPUT_TYPE = 12i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SIT_UAV_FEEDBACKTEXTURE: D3D_SHADER_INPUT_TYPE = 13i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SIT_CBUFFER: D3D_SHADER_INPUT_TYPE = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SIT_TBUFFER: D3D_SHADER_INPUT_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SIT_TEXTURE: D3D_SHADER_INPUT_TYPE = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SIT_SAMPLER: D3D_SHADER_INPUT_TYPE = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SIT_UAV_RWTYPED: D3D_SHADER_INPUT_TYPE = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SIT_STRUCTURED: D3D_SHADER_INPUT_TYPE = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SIT_UAV_RWSTRUCTURED: D3D_SHADER_INPUT_TYPE = 6i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SIT_BYTEADDRESS: D3D_SHADER_INPUT_TYPE = 7i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SIT_UAV_RWBYTEADDRESS: D3D_SHADER_INPUT_TYPE = 8i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SIT_UAV_APPEND_STRUCTURED: D3D_SHADER_INPUT_TYPE = 9i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SIT_UAV_CONSUME_STRUCTURED: D3D_SHADER_INPUT_TYPE = 10i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SIT_UAV_RWSTRUCTURED_WITH_COUNTER: D3D_SHADER_INPUT_TYPE = 11i32;
#[repr(C)]
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub struct D3D_SHADER_MACRO {
    pub Name: ::windows_sys::core::PCSTR,
    pub Definition: ::windows_sys::core::PCSTR,
}
impl ::core::marker::Copy for D3D_SHADER_MACRO {}
impl ::core::clone::Clone for D3D_SHADER_MACRO {
    fn clone(&self) -> Self {
        *self
    }
}
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_SHADER_VARIABLE_CLASS = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVC_SCALAR: D3D_SHADER_VARIABLE_CLASS = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVC_VECTOR: D3D_SHADER_VARIABLE_CLASS = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVC_MATRIX_ROWS: D3D_SHADER_VARIABLE_CLASS = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVC_MATRIX_COLUMNS: D3D_SHADER_VARIABLE_CLASS = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVC_OBJECT: D3D_SHADER_VARIABLE_CLASS = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVC_STRUCT: D3D_SHADER_VARIABLE_CLASS = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVC_INTERFACE_CLASS: D3D_SHADER_VARIABLE_CLASS = 6i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVC_INTERFACE_POINTER: D3D_SHADER_VARIABLE_CLASS = 7i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVC_SCALAR: D3D_SHADER_VARIABLE_CLASS = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVC_VECTOR: D3D_SHADER_VARIABLE_CLASS = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVC_MATRIX_ROWS: D3D_SHADER_VARIABLE_CLASS = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVC_MATRIX_COLUMNS: D3D_SHADER_VARIABLE_CLASS = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVC_OBJECT: D3D_SHADER_VARIABLE_CLASS = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVC_STRUCT: D3D_SHADER_VARIABLE_CLASS = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVC_INTERFACE_CLASS: D3D_SHADER_VARIABLE_CLASS = 6i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVC_INTERFACE_POINTER: D3D_SHADER_VARIABLE_CLASS = 7i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVC_FORCE_DWORD: D3D_SHADER_VARIABLE_CLASS = 2147483647i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_SHADER_VARIABLE_FLAGS = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVF_USERPACKED: D3D_SHADER_VARIABLE_FLAGS = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVF_USED: D3D_SHADER_VARIABLE_FLAGS = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVF_INTERFACE_POINTER: D3D_SHADER_VARIABLE_FLAGS = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVF_INTERFACE_PARAMETER: D3D_SHADER_VARIABLE_FLAGS = 8i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVF_USERPACKED: D3D_SHADER_VARIABLE_FLAGS = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVF_USED: D3D_SHADER_VARIABLE_FLAGS = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVF_INTERFACE_POINTER: D3D_SHADER_VARIABLE_FLAGS = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVF_INTERFACE_PARAMETER: D3D_SHADER_VARIABLE_FLAGS = 8i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVF_FORCE_DWORD: D3D_SHADER_VARIABLE_FLAGS = 2147483647i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_SHADER_VARIABLE_TYPE = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_VOID: D3D_SHADER_VARIABLE_TYPE = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_BOOL: D3D_SHADER_VARIABLE_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_INT: D3D_SHADER_VARIABLE_TYPE = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_FLOAT: D3D_SHADER_VARIABLE_TYPE = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_STRING: D3D_SHADER_VARIABLE_TYPE = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_TEXTURE: D3D_SHADER_VARIABLE_TYPE = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_TEXTURE1D: D3D_SHADER_VARIABLE_TYPE = 6i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_TEXTURE2D: D3D_SHADER_VARIABLE_TYPE = 7i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_TEXTURE3D: D3D_SHADER_VARIABLE_TYPE = 8i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_TEXTURECUBE: D3D_SHADER_VARIABLE_TYPE = 9i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_SAMPLER: D3D_SHADER_VARIABLE_TYPE = 10i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_SAMPLER1D: D3D_SHADER_VARIABLE_TYPE = 11i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_SAMPLER2D: D3D_SHADER_VARIABLE_TYPE = 12i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_SAMPLER3D: D3D_SHADER_VARIABLE_TYPE = 13i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_SAMPLERCUBE: D3D_SHADER_VARIABLE_TYPE = 14i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_PIXELSHADER: D3D_SHADER_VARIABLE_TYPE = 15i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_VERTEXSHADER: D3D_SHADER_VARIABLE_TYPE = 16i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_PIXELFRAGMENT: D3D_SHADER_VARIABLE_TYPE = 17i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_VERTEXFRAGMENT: D3D_SHADER_VARIABLE_TYPE = 18i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_UINT: D3D_SHADER_VARIABLE_TYPE = 19i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_UINT8: D3D_SHADER_VARIABLE_TYPE = 20i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_GEOMETRYSHADER: D3D_SHADER_VARIABLE_TYPE = 21i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_RASTERIZER: D3D_SHADER_VARIABLE_TYPE = 22i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_DEPTHSTENCIL: D3D_SHADER_VARIABLE_TYPE = 23i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_BLEND: D3D_SHADER_VARIABLE_TYPE = 24i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_BUFFER: D3D_SHADER_VARIABLE_TYPE = 25i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_CBUFFER: D3D_SHADER_VARIABLE_TYPE = 26i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_TBUFFER: D3D_SHADER_VARIABLE_TYPE = 27i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_TEXTURE1DARRAY: D3D_SHADER_VARIABLE_TYPE = 28i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_TEXTURE2DARRAY: D3D_SHADER_VARIABLE_TYPE = 29i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_RENDERTARGETVIEW: D3D_SHADER_VARIABLE_TYPE = 30i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_DEPTHSTENCILVIEW: D3D_SHADER_VARIABLE_TYPE = 31i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_TEXTURE2DMS: D3D_SHADER_VARIABLE_TYPE = 32i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_TEXTURE2DMSARRAY: D3D_SHADER_VARIABLE_TYPE = 33i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_TEXTURECUBEARRAY: D3D_SHADER_VARIABLE_TYPE = 34i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_HULLSHADER: D3D_SHADER_VARIABLE_TYPE = 35i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_DOMAINSHADER: D3D_SHADER_VARIABLE_TYPE = 36i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_INTERFACE_POINTER: D3D_SHADER_VARIABLE_TYPE = 37i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_COMPUTESHADER: D3D_SHADER_VARIABLE_TYPE = 38i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_DOUBLE: D3D_SHADER_VARIABLE_TYPE = 39i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_RWTEXTURE1D: D3D_SHADER_VARIABLE_TYPE = 40i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_RWTEXTURE1DARRAY: D3D_SHADER_VARIABLE_TYPE = 41i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_RWTEXTURE2D: D3D_SHADER_VARIABLE_TYPE = 42i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_RWTEXTURE2DARRAY: D3D_SHADER_VARIABLE_TYPE = 43i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_RWTEXTURE3D: D3D_SHADER_VARIABLE_TYPE = 44i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_RWBUFFER: D3D_SHADER_VARIABLE_TYPE = 45i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_BYTEADDRESS_BUFFER: D3D_SHADER_VARIABLE_TYPE = 46i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_RWBYTEADDRESS_BUFFER: D3D_SHADER_VARIABLE_TYPE = 47i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_STRUCTURED_BUFFER: D3D_SHADER_VARIABLE_TYPE = 48i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_RWSTRUCTURED_BUFFER: D3D_SHADER_VARIABLE_TYPE = 49i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_APPEND_STRUCTURED_BUFFER: D3D_SHADER_VARIABLE_TYPE = 50i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_CONSUME_STRUCTURED_BUFFER: D3D_SHADER_VARIABLE_TYPE = 51i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_MIN8FLOAT: D3D_SHADER_VARIABLE_TYPE = 52i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_MIN10FLOAT: D3D_SHADER_VARIABLE_TYPE = 53i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_MIN16FLOAT: D3D_SHADER_VARIABLE_TYPE = 54i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_MIN12INT: D3D_SHADER_VARIABLE_TYPE = 55i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_MIN16INT: D3D_SHADER_VARIABLE_TYPE = 56i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_MIN16UINT: D3D_SHADER_VARIABLE_TYPE = 57i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_INT16: D3D_SHADER_VARIABLE_TYPE = 58i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_UINT16: D3D_SHADER_VARIABLE_TYPE = 59i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_FLOAT16: D3D_SHADER_VARIABLE_TYPE = 60i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_INT64: D3D_SHADER_VARIABLE_TYPE = 61i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_UINT64: D3D_SHADER_VARIABLE_TYPE = 62i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_VOID: D3D_SHADER_VARIABLE_TYPE = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_BOOL: D3D_SHADER_VARIABLE_TYPE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_INT: D3D_SHADER_VARIABLE_TYPE = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_FLOAT: D3D_SHADER_VARIABLE_TYPE = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_STRING: D3D_SHADER_VARIABLE_TYPE = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_TEXTURE: D3D_SHADER_VARIABLE_TYPE = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_TEXTURE1D: D3D_SHADER_VARIABLE_TYPE = 6i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_TEXTURE2D: D3D_SHADER_VARIABLE_TYPE = 7i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_TEXTURE3D: D3D_SHADER_VARIABLE_TYPE = 8i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_TEXTURECUBE: D3D_SHADER_VARIABLE_TYPE = 9i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_SAMPLER: D3D_SHADER_VARIABLE_TYPE = 10i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_SAMPLER1D: D3D_SHADER_VARIABLE_TYPE = 11i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_SAMPLER2D: D3D_SHADER_VARIABLE_TYPE = 12i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_SAMPLER3D: D3D_SHADER_VARIABLE_TYPE = 13i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_SAMPLERCUBE: D3D_SHADER_VARIABLE_TYPE = 14i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_PIXELSHADER: D3D_SHADER_VARIABLE_TYPE = 15i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_VERTEXSHADER: D3D_SHADER_VARIABLE_TYPE = 16i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_PIXELFRAGMENT: D3D_SHADER_VARIABLE_TYPE = 17i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_VERTEXFRAGMENT: D3D_SHADER_VARIABLE_TYPE = 18i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_UINT: D3D_SHADER_VARIABLE_TYPE = 19i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_UINT8: D3D_SHADER_VARIABLE_TYPE = 20i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_GEOMETRYSHADER: D3D_SHADER_VARIABLE_TYPE = 21i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_RASTERIZER: D3D_SHADER_VARIABLE_TYPE = 22i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_DEPTHSTENCIL: D3D_SHADER_VARIABLE_TYPE = 23i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_BLEND: D3D_SHADER_VARIABLE_TYPE = 24i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_BUFFER: D3D_SHADER_VARIABLE_TYPE = 25i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_CBUFFER: D3D_SHADER_VARIABLE_TYPE = 26i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_TBUFFER: D3D_SHADER_VARIABLE_TYPE = 27i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_TEXTURE1DARRAY: D3D_SHADER_VARIABLE_TYPE = 28i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_TEXTURE2DARRAY: D3D_SHADER_VARIABLE_TYPE = 29i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_RENDERTARGETVIEW: D3D_SHADER_VARIABLE_TYPE = 30i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_DEPTHSTENCILVIEW: D3D_SHADER_VARIABLE_TYPE = 31i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_TEXTURE2DMS: D3D_SHADER_VARIABLE_TYPE = 32i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_TEXTURE2DMSARRAY: D3D_SHADER_VARIABLE_TYPE = 33i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SVT_TEXTURECUBEARRAY: D3D_SHADER_VARIABLE_TYPE = 34i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVT_HULLSHADER: D3D_SHADER_VARIABLE_TYPE = 35i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVT_DOMAINSHADER: D3D_SHADER_VARIABLE_TYPE = 36i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVT_INTERFACE_POINTER: D3D_SHADER_VARIABLE_TYPE = 37i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVT_COMPUTESHADER: D3D_SHADER_VARIABLE_TYPE = 38i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVT_DOUBLE: D3D_SHADER_VARIABLE_TYPE = 39i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVT_RWTEXTURE1D: D3D_SHADER_VARIABLE_TYPE = 40i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVT_RWTEXTURE1DARRAY: D3D_SHADER_VARIABLE_TYPE = 41i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVT_RWTEXTURE2D: D3D_SHADER_VARIABLE_TYPE = 42i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVT_RWTEXTURE2DARRAY: D3D_SHADER_VARIABLE_TYPE = 43i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVT_RWTEXTURE3D: D3D_SHADER_VARIABLE_TYPE = 44i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVT_RWBUFFER: D3D_SHADER_VARIABLE_TYPE = 45i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVT_BYTEADDRESS_BUFFER: D3D_SHADER_VARIABLE_TYPE = 46i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVT_RWBYTEADDRESS_BUFFER: D3D_SHADER_VARIABLE_TYPE = 47i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVT_STRUCTURED_BUFFER: D3D_SHADER_VARIABLE_TYPE = 48i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVT_RWSTRUCTURED_BUFFER: D3D_SHADER_VARIABLE_TYPE = 49i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVT_APPEND_STRUCTURED_BUFFER: D3D_SHADER_VARIABLE_TYPE = 50i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SVT_CONSUME_STRUCTURED_BUFFER: D3D_SHADER_VARIABLE_TYPE = 51i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SVT_FORCE_DWORD: D3D_SHADER_VARIABLE_TYPE = 2147483647i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_SRV_DIMENSION = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SRV_DIMENSION_UNKNOWN: D3D_SRV_DIMENSION = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SRV_DIMENSION_BUFFER: D3D_SRV_DIMENSION = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SRV_DIMENSION_TEXTURE1D: D3D_SRV_DIMENSION = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SRV_DIMENSION_TEXTURE1DARRAY: D3D_SRV_DIMENSION = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SRV_DIMENSION_TEXTURE2D: D3D_SRV_DIMENSION = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SRV_DIMENSION_TEXTURE2DARRAY: D3D_SRV_DIMENSION = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SRV_DIMENSION_TEXTURE2DMS: D3D_SRV_DIMENSION = 6i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SRV_DIMENSION_TEXTURE2DMSARRAY: D3D_SRV_DIMENSION = 7i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SRV_DIMENSION_TEXTURE3D: D3D_SRV_DIMENSION = 8i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SRV_DIMENSION_TEXTURECUBE: D3D_SRV_DIMENSION = 9i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SRV_DIMENSION_TEXTURECUBEARRAY: D3D_SRV_DIMENSION = 10i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_SRV_DIMENSION_BUFFEREX: D3D_SRV_DIMENSION = 11i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SRV_DIMENSION_UNKNOWN: D3D_SRV_DIMENSION = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SRV_DIMENSION_BUFFER: D3D_SRV_DIMENSION = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SRV_DIMENSION_TEXTURE1D: D3D_SRV_DIMENSION = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SRV_DIMENSION_TEXTURE1DARRAY: D3D_SRV_DIMENSION = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SRV_DIMENSION_TEXTURE2D: D3D_SRV_DIMENSION = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SRV_DIMENSION_TEXTURE2DARRAY: D3D_SRV_DIMENSION = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SRV_DIMENSION_TEXTURE2DMS: D3D_SRV_DIMENSION = 6i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SRV_DIMENSION_TEXTURE2DMSARRAY: D3D_SRV_DIMENSION = 7i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SRV_DIMENSION_TEXTURE3D: D3D_SRV_DIMENSION = 8i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_SRV_DIMENSION_TEXTURECUBE: D3D_SRV_DIMENSION = 9i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_1_SRV_DIMENSION_UNKNOWN: D3D_SRV_DIMENSION = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_1_SRV_DIMENSION_BUFFER: D3D_SRV_DIMENSION = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_1_SRV_DIMENSION_TEXTURE1D: D3D_SRV_DIMENSION = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_1_SRV_DIMENSION_TEXTURE1DARRAY: D3D_SRV_DIMENSION = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_1_SRV_DIMENSION_TEXTURE2D: D3D_SRV_DIMENSION = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_1_SRV_DIMENSION_TEXTURE2DARRAY: D3D_SRV_DIMENSION = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_1_SRV_DIMENSION_TEXTURE2DMS: D3D_SRV_DIMENSION = 6i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_1_SRV_DIMENSION_TEXTURE2DMSARRAY: D3D_SRV_DIMENSION = 7i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_1_SRV_DIMENSION_TEXTURE3D: D3D_SRV_DIMENSION = 8i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_1_SRV_DIMENSION_TEXTURECUBE: D3D_SRV_DIMENSION = 9i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D10_1_SRV_DIMENSION_TEXTURECUBEARRAY: D3D_SRV_DIMENSION = 10i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SRV_DIMENSION_UNKNOWN: D3D_SRV_DIMENSION = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SRV_DIMENSION_BUFFER: D3D_SRV_DIMENSION = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SRV_DIMENSION_TEXTURE1D: D3D_SRV_DIMENSION = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SRV_DIMENSION_TEXTURE1DARRAY: D3D_SRV_DIMENSION = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SRV_DIMENSION_TEXTURE2D: D3D_SRV_DIMENSION = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SRV_DIMENSION_TEXTURE2DARRAY: D3D_SRV_DIMENSION = 5i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SRV_DIMENSION_TEXTURE2DMS: D3D_SRV_DIMENSION = 6i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SRV_DIMENSION_TEXTURE2DMSARRAY: D3D_SRV_DIMENSION = 7i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SRV_DIMENSION_TEXTURE3D: D3D_SRV_DIMENSION = 8i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SRV_DIMENSION_TEXTURECUBE: D3D_SRV_DIMENSION = 9i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SRV_DIMENSION_TEXTURECUBEARRAY: D3D_SRV_DIMENSION = 10i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_SRV_DIMENSION_BUFFEREX: D3D_SRV_DIMENSION = 11i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_TESSELLATOR_DOMAIN = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_TESSELLATOR_DOMAIN_UNDEFINED: D3D_TESSELLATOR_DOMAIN = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_TESSELLATOR_DOMAIN_ISOLINE: D3D_TESSELLATOR_DOMAIN = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_TESSELLATOR_DOMAIN_TRI: D3D_TESSELLATOR_DOMAIN = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_TESSELLATOR_DOMAIN_QUAD: D3D_TESSELLATOR_DOMAIN = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_TESSELLATOR_DOMAIN_UNDEFINED: D3D_TESSELLATOR_DOMAIN = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_TESSELLATOR_DOMAIN_ISOLINE: D3D_TESSELLATOR_DOMAIN = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_TESSELLATOR_DOMAIN_TRI: D3D_TESSELLATOR_DOMAIN = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_TESSELLATOR_DOMAIN_QUAD: D3D_TESSELLATOR_DOMAIN = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_TESSELLATOR_OUTPUT_PRIMITIVE = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_TESSELLATOR_OUTPUT_UNDEFINED: D3D_TESSELLATOR_OUTPUT_PRIMITIVE = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_TESSELLATOR_OUTPUT_POINT: D3D_TESSELLATOR_OUTPUT_PRIMITIVE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_TESSELLATOR_OUTPUT_LINE: D3D_TESSELLATOR_OUTPUT_PRIMITIVE = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_TESSELLATOR_OUTPUT_TRIANGLE_CW: D3D_TESSELLATOR_OUTPUT_PRIMITIVE = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_TESSELLATOR_OUTPUT_TRIANGLE_CCW: D3D_TESSELLATOR_OUTPUT_PRIMITIVE = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_TESSELLATOR_OUTPUT_UNDEFINED: D3D_TESSELLATOR_OUTPUT_PRIMITIVE = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_TESSELLATOR_OUTPUT_POINT: D3D_TESSELLATOR_OUTPUT_PRIMITIVE = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_TESSELLATOR_OUTPUT_LINE: D3D_TESSELLATOR_OUTPUT_PRIMITIVE = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_TESSELLATOR_OUTPUT_TRIANGLE_CW: D3D_TESSELLATOR_OUTPUT_PRIMITIVE = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_TESSELLATOR_OUTPUT_TRIANGLE_CCW: D3D_TESSELLATOR_OUTPUT_PRIMITIVE = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type D3D_TESSELLATOR_PARTITIONING = i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_TESSELLATOR_PARTITIONING_UNDEFINED: D3D_TESSELLATOR_PARTITIONING = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_TESSELLATOR_PARTITIONING_INTEGER: D3D_TESSELLATOR_PARTITIONING = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_TESSELLATOR_PARTITIONING_POW2: D3D_TESSELLATOR_PARTITIONING = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_TESSELLATOR_PARTITIONING_FRACTIONAL_ODD: D3D_TESSELLATOR_PARTITIONING = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D_TESSELLATOR_PARTITIONING_FRACTIONAL_EVEN: D3D_TESSELLATOR_PARTITIONING = 4i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_TESSELLATOR_PARTITIONING_UNDEFINED: D3D_TESSELLATOR_PARTITIONING = 0i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_TESSELLATOR_PARTITIONING_INTEGER: D3D_TESSELLATOR_PARTITIONING = 1i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_TESSELLATOR_PARTITIONING_POW2: D3D_TESSELLATOR_PARTITIONING = 2i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_TESSELLATOR_PARTITIONING_FRACTIONAL_ODD: D3D_TESSELLATOR_PARTITIONING = 3i32;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub const D3D11_TESSELLATOR_PARTITIONING_FRACTIONAL_EVEN: D3D_TESSELLATOR_PARTITIONING = 4i32;
pub const D3D_TEXTURE_LAYOUT_64KB_STANDARD_SWIZZLE: ::windows_sys::core::GUID = ::windows_sys::core::GUID { data1: 1276062179, data2: 16223, data3: 19765, data4: [132, 201, 188, 9, 131, 182, 44, 40] };
pub const D3D_TEXTURE_LAYOUT_ROW_MAJOR: ::windows_sys::core::GUID = ::windows_sys::core::GUID { data1: 3051103055, data2: 29371, data3: 19436, data4: [151, 5, 140, 242, 88, 223, 107, 108] };
pub type ID3DBlob = *mut ::core::ffi::c_void;
pub type ID3DDestructionNotifier = *mut ::core::ffi::c_void;
pub type ID3DInclude = *mut ::core::ffi::c_void;
#[doc = "*Required features: `\"Win32_Graphics_Direct3D\"`*"]
pub type PFN_DESTRUCTION_CALLBACK = ::core::option::Option<unsafe extern "system" fn(pdata: *mut ::core::ffi::c_void)>;
pub const WKPDID_CommentStringW: ::windows_sys::core::GUID = ::windows_sys::core::GUID { data1: 3491012032, data2: 37096, data3: 20168, data4: [129, 68, 233, 0, 173, 38, 107, 178] };
pub const WKPDID_D3D12UniqueObjectId: ::windows_sys::core::GUID = ::windows_sys::core::GUID { data1: 456777237, data2: 60420, data3: 19374, data4: [186, 77, 140, 239, 121, 252, 4, 193] };
pub const WKPDID_D3DDebugObjectName: ::windows_sys::core::GUID = ::windows_sys::core::GUID { data1: 1117490210, data2: 37256, data3: 19212, data4: [135, 66, 172, 176, 191, 133, 194, 0] };
pub const WKPDID_D3DDebugObjectNameW: ::windows_sys::core::GUID = ::windows_sys::core::GUID { data1: 1288331224, data2: 37407, data3: 17096, data4: [133, 102, 112, 202, 242, 169, 183, 65] };
